==> b3fileparser-0.1.2.tar.gz: b3fileparser-0.1.2/b3fileparser/b3_meta_data.py <==
META_DATA = {    
    "TIPREG":{'name':"TIPO_DE_REGISTRO", 'size':2 },
    "DATAPR":{'name':"DATA_DO_PREGAO", 'size':8},
    "CODBDI":{'name':"CODIGO_BDI", 'size':2},
    "CODNEG":{'name':"CODIGO_DE_NEGOCIACAO",'size':12},
    "TPMERC":{'name':"TIPO_DE_MERCADO",'size':3},
    "NOMRES":{'name':"NOME_DA_EMPRESA",'size':12},
    "ESPECI":{'name':"ESPECIFICACAO_DO_PAPEL",'size':10},
    "PRAZOT":{'name':"PRAZO_EM_DIAS_DO_MERCADO_A_TERMO",'size':3},
    "MODREF":{'name':"MOEDA_DE_REFERENCIA",'size':4},
    "PREABE":{'name':"PRECO_DE_ABERTURA",'size':13},
    "PREMAX":{'name':"PRECO_MAXIMO",'size':13},
    "PREMIN":{'name':"PRECO_MINIMO",'size':13},
    "PREMED":{'name':"PRECO_MEDIO",'size':13},
    "PREULT":{'name':"PRECO_ULTIMO_NEGOCIO",'size':13},
    "PREOFC":{'name':"PRECO_MELHOR_OFERTA_DE_COMPRA",'size':13},
    "PREOFV":{'name':"PRECO_MELHOR_OFERTA_DE_VENDAS",'size':13},
    "TOTNEG":{'name':"NUMERO_DE_NEGOCIOS",'size':5},
    "QUATOT":{'name':"QUANTIDADE_NEGOCIADA",'size':18},
    "VOLTOT":{'name':"VOLUME_TOTAL_NEGOCIADO",'size':18},
    "PREEXE":{'name':"PRECO_DE_EXERCICIO",'size':13},
    "INDOPC":{'name':"INDICADOR_DE_CORRECAO_DE_PRECOS",'size':1},
    "DATVEN":{'name':"DATA_DE_VENCIMENTO",'size':8},
    "FATCOT":{'name':"FATOR_DE_COTACAO",'size':7},
    "PTOEXE":{'name':"PRECO_DE_EXERCICIO_EM_PONTOS",'size':13},
    "CODISI":{'name':"CODIGO_ISIN",'size':12},
    "DISMES":{'name':"NUMERO_DE_DISTRIBUICAO",'size':3}
}


MARKETS = {
    10:'VISTA',
    12:'EXERCICIO DE OPCOES DE COMPRA',
    13:'EXERCÍCIO DE OPCOES DE VENDA',
    17:'LEILAO',
    20:'FRACIONARIO',
    30:'TERMO',
    50:'FUTURO_COM_RETENCAO_DE_GANHO',
    60:'FUTURO_COM_MOVIMENTACAO_CONTINUA',
    70:'OPCOES_DE_COMPRA',
    80:'OPCOES_DE_VENDA'
}

INDOPC = {
    0:'0',
    1:'US$',
    2:"TJLP",
    8:"IGPM",
    9:"URV"
}

CODBDI = {
    0:'0',
    2:"LOTE_PADRAO",
    5:"SANCIONADAS PELOS REGULAMENTOS BMFBOVESPA",
    6:"CONCORDATARIAS",
    7:"RECUPERACAO_EXTRAJUDICIAL",
    8:"RECUPERAÇÃO_JUDICIAL",
    9:"REGIME_DE_ADMINISTRACAO_ESPECIAL_TEMPORARIA",
    10:"DIREITOS E RECIBOS",
    11:"INTERVENCAO",
    12:"FUNDOS IMOBILIARIOS",
    13:'13',
    14:"CERT.INVEST/TIT.DIV.PUBLICA",
    18:"OBRIGACÕES",
    22:"BÔNUS (PRIVADOS)",
    26:"APOLICES/BÔNUS/TITULOS PUBLICOS",
    32:"EXERCICIO DE OPCOES DE COMPRA DE INDICES",
    33:"EXERCICIO DE OPCOES DE VENDA DE INDICES",
    34:'34',
    35:'35',
    36:'36',
    37:'37',
    38:"EXERCICIO DE OPCOES DE COMPRA",
    42:"EXERCICIO DE OPCOES DE VENDA",
    46:"LEILAO DE NAO COTADOS",
    48:"LEILAO DE PRIVATIZACAO",
    49:"LEILAO DO FUNDO RECUPERACAO ECONOMICA ESPIRITO SANTO",
    50:"LEILAO",
    51:"LEILAO FINOR",
    52:"LEILAO FINAM",
    53:"LEILAO FISET",
    54:"LEILAO DE ACÕES EM MORA",
    56:"VENDAS POR ALVARA JUDICIAL",
    58:"OUTROS",
    60:"PERMUTA POR ACÕES",
    61:"META",
    62:"MERCADO A TERMO",
    66:"DEBENTURES COM DATA DE VENCIMENTO ATE 3 ANOS",
    68:"DEBENTURES COM DATA DE VENCIMENTO MAIOR QUE 3 ANOS",
    70:"FUTURO COM RETENCAO DE GANHOS",
    71:"MERCADO DE FUTURO",
    74:"OPCOES DE COMPRA DE INDICES",
    75:"OPCOES DE VENDA DE INDICES",
    78:"OPCOES DE COMPRA",
    82:"OPCOES DE VENDA",
    83:"BOVESPAFIX",
    84:"SOMA FIX",
    90:"TERMO VISTA REGISTRADO",
    96:"MERCADO FRACIONARIO",
    99:"TOTAL GERAL"
}

==> b3fileparser-0.1.3.tar.gz: b3fileparser-0.1.3/b3fileparser/b3_meta_data.py <==
META_DATA = {    
    "TIPREG":{'name':"TIPO_DE_REGISTRO", 'size':2 },
    "DATAPR":{'name':"DATA_DO_PREGAO", 'size':8},
    "CODBDI":{'name':"CODIGO_BDI", 'size':2},
    "CODNEG":{'name':"CODIGO_DE_NEGOCIACAO",'size':12},
    "TPMERC":{'name':"TIPO_DE_MERCADO",'size':3},
    "NOMRES":{'name':"NOME_DA_EMPRESA",'size':12},
    "ESPECI":{'name':"ESPECIFICACAO_DO_PAPEL",'size':10},
    "PRAZOT":{'name':"PRAZO_EM_DIAS_DO_MERCADO_A_TERMO",'size':3},
    "MODREF":{'name':"MOEDA_DE_REFERENCIA",'size':4},
    "PREABE":{'name':"PRECO_DE_ABERTURA",'size':13},
    "PREMAX":{'name':"PRECO_MAXIMO",'size':13},
    "PREMIN":{'name':"PRECO_MINIMO",'size':13},
    "PREMED":{'name':"PRECO_MEDIO",'size':13},
    "PREULT":{'name':"PRECO_ULTIMO_NEGOCIO",'size':13},
    "PREOFC":{'name':"PRECO_MELHOR_OFERTA_DE_COMPRA",'size':13},
    "PREOFV":{'name':"PRECO_MELHOR_OFERTA_DE_VENDAS",'size':13},
    "TOTNEG":{'name':"NUMERO_DE_NEGOCIOS",'size':5},
    "QUATOT":{'name':"QUANTIDADE_NEGOCIADA",'size':18},
    "VOLTOT":{'name':"VOLUME_TOTAL_NEGOCIADO",'size':18},
    "PREEXE":{'name':"PRECO_DE_EXERCICIO",'size':13},
    "INDOPC":{'name':"INDICADOR_DE_CORRECAO_DE_PRECOS",'size':1},
    "DATVEN":{'name':"DATA_DE_VENCIMENTO",'size':8},
    "FATCOT":{'name':"FATOR_DE_COTACAO",'size':7},
    "PTOEXE":{'name':"PRECO_DE_EXERCICIO_EM_PONTOS",'size':13},
    "CODISI":{'name':"CODIGO_ISIN",'size':12},
    "DISMES":{'name':"NUMERO_DE_DISTRIBUICAO",'size':3}
}


MARKETS = {
    10:'VISTA',
    12:'EXERCICIO_DE_OPCOES_DE_COMPRA',
    13:'EXERCÍCIO_DE_OPCOES_DE_VENDA',
    17:'LEILAO',
    20:'FRACIONARIO',
    30:'TERMO',
    50:'FUTURO_COM_RETENCAO_DE_GANHO',
    60:'FUTURO_COM_MOVIMENTACAO_CONTINUA',
    70:'OPCOES_DE_COMPRA',
    80:'OPCOES_DE_VENDA'
}

INDOPC = {
    0:'0',
    1:'US$',
    2:"TJLP",
    8:"IGPM",
    9:"URV"
}

CODBDI = {
    0:'0',
    2:"LOTE_PADRAO",
    5:"SANCIONADAS PELOS REGULAMENTOS BMFBOVESPA",
    6:"CONCORDATARIAS",
    7:"RECUPERACAO_EXTRAJUDICIAL",
    8:"RECUPERAÇÃO_JUDICIAL",
    9:"REGIME_DE_ADMINISTRACAO_ESPECIAL_TEMPORARIA",
    10:"DIREITOS_E_RECIBOS",
    11:"INTERVENCAO",
    12:"FUNDOS_IMOBILIARIOS",
    13:'13',
    14:"CERT.INVEST/TIT.DIV.PUBLICA",
    18:"OBRIGACÕES",
    22:"BÔNUS(PRIVADOS)",
    26:"APOLICES/BÔNUS/TITULOS PUBLICOS",
    32:"EXERCICIO_DE_OPCOES_DE_COMPRA_DE_INDICES",
    33:"EXERCICIO_DE_OPCOES_DE_VENDA_DE_INDICES",
    34:'34',
    35:'35',
    36:'36',
    37:'37',
    38:"EXERCICIO_DE_OPCOES_DE_COMPRA",
    42:"EXERCICIO_DE_OPCOES_DE_VENDA",
    46:"LEILAO_DE_NAO_COTADOS",
    48:"LEILAO_DE_PRIVATIZACAO",
    49:"LEILAO_DO_FUNDO_RECUPERACAO_ECONOMICA_ESPIRITO_SANTO",
    50:"LEILAO",
    51:"LEILAO_FINOR",
    52:"LEILAO_FINAM",
    53:"LEILAO_FISET",
    54:"LEILAO_DE_ACÕES_EM_MORA",
    56:"VENDAS_POR_ALVARA_JUDICIAL",
    58:"OUTROS",
    60:"PERMUTA_POR_ACÕES",
    61:"META",
    62:"MERCADO_A_TERMO",
    66:"DEBENTURES_COM_DATA_DE_VENCIMENTO_ATE_3_ANOS",
    68:"DEBENTURES_COM_DATA_DE_VENCIMENTO_MAIOR_QUE_3_ANOS",
    70:"FUTURO_COM_RETENCAO_DE_GANHOS",
    71:"MERCADO_DE_FUTURO",
    74:"OPCOES_DE_COMPRA_DE_INDICES",
    75:"OPCOES_DE_VENDA_DE_INDICES",
    78:"OPCOES_DE_COMPRA",
    82:"OPCOES_DE_VENDA",
    83:"BOVESPAFIX",
    84:"SOMA_FIX",
    90:"TERMO_VISTA_REGISTRADO",
    96:"MERCADO_FRACIONARIO",
    99:"TOTAL_GERAL"
}
